import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'faultCode',
    label: '知识编号'
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'Input',
    fieldName: 'assetNo',
    label: '资产编号'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_EQU_PART)
    },
    fieldName: 'equPart',
    label: '设备部位'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.REPAIR_FAULT_TYPE)
    },
    fieldName: 'faultType',
    label: '故障类别'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_FAULT_REASON)
    },
    fieldName: 'faultReason',
    label: '故障原因'
  },
  {
    component: 'Input',
    fieldName: 'reqDesc',
    label: '故障描述'
  },
  {
    component: 'Input',
    fieldName: 'resHandle',
    label: '处理措施'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '知识编码',
    field: 'faultCode',
    minWidth: 200
  },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 140,
    fixed: 'left',
    slots: { default: 'equName' }
  },
  {
    title: '资产编号',
    field: 'assetNo',
    sortable: true,
    minWidth: 140,
    fixed: 'left'
  },
  {
    title: '设备类型',
    field: 'equTypeName',
    minWidth: 140
  },
  {
    title: '设备部位',
    field: 'equPart',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.equPart === null || row.equPart === '') {
          return '';
        }
        return renderDict(row.equPart, DictEnum.EIMS_EQU_PART);
      }
    },
    minWidth: 120
  },
  {
    title: '故障类别',
    field: 'faultType',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.faultType === null || row.faultType === '') {
          return '';
        }
        return renderDict(row.faultType, DictEnum.REPAIR_FAULT_TYPE);
      }
    },
    minWidth: 120
  },
  {
    title: '故障原因',
    field: 'faultReason',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.faultReason === null || row.faultReason === '') {
          return '';
        }
        return renderDict(row.faultReason, DictEnum.EIMS_FAULT_REASON);
      }
    },
    minWidth: 120
  },
  {
    title: '报修描述',
    field: 'reqDesc',
    minWidth: 300
  },
  {
    title: '处理措施',
    field: 'resHandle',
    minWidth: 300
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'equId'
  },
  {
    component: 'Input',
    fieldName: 'faultCode',
    label: '知识编码',
    rules: 'required'
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称',
    rules: 'required'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_EQU_PART)
    },
    fieldName: 'equPart',
    label: '设备部位'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.REPAIR_FAULT_TYPE)
    },
    fieldName: 'faultType',
    label: '故障类别'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_FAULT_REASON)
    },
    fieldName: 'faultReason',
    label: '故障原因'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'reqDesc',
    label: '报修描述'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'resHandle',
    label: '处理措施'
  }
];
